function [Y, err] = cportgetint( H, nbyte, S, C );

% [Y,err] = cportgetint(H,nbyte,S) retrieves integer words from a 
% previously opened serial or parallel port. The parameters are:
% 
% Input:
% ------
%   H     - The port handle returned by cportopen.
%   nbyte - The number of bytes in a word (default 2).
%   S     - The size of the output array (default [1 1]).
%   C     - Complex (Boolean) (default 0)
%
% Output:
% -------
%   Y     - A numeric array containing the retreived words.
%   err   - Optional error flag, 1 for success and 0 for failure.
%
% The bit order is lowest to highest, real and imaginary interleaved
%
error('CPORTGETINT is implemented in a MEX file.');
